@@ -15,6 +15,10 @@
 #'@param dec The precision of the data, which defaults to 2 decimal places.
 #'@param nonnormal When the data belongs to a non-normal distribution, this parameter is needed to indicate which is variable is non-normally distributed.
 #'@param statistic Statistical effect values. Usually, it is the default F, and selecting T will return a statistical effect value.
+#'@param fisher Fisher's exact test. The default is FALSE.
+#'@param correct Chi square test for continuity correction.The default is FALSE.
+#'@param Overall Generate summary data.The default is FALSE.
+#'@importFrom  "stats" "fisher.test"
 #'
 #'@return A data frame.
 
@@ -22,9 +26,11 @@ utils::globalVariables(c('chisq.test'
 ))
 
 
-sci1freq<- function(mvars,x,data,dec,nonnormal=NULL,statistic=NULL) {
+sci1freq<- function(mvars,x,data,dec,nonnormal=NULL,statistic=NULL,fisher=NULL,
+                    correct=NULL,Overall=NULL) {
   options(warn=-1)
   mvars<-mvars;x<-x;data<-data;nonnormal<-nonnormal
+  fisher<-fisher;correct<-correct;Overall<-Overall
   if (missing(dec)) {dec<-2} else {dec<-dec}
   xvt<-data[,x];nc<-length(mvars);varsdt<-data[,mvars];
   if (nc==1) varsdt<-as.matrix(varsdt,ncol=nc)
@@ -33,24 +39,45 @@ sci1freq<- function(mvars,x,data,dec,nonnormal=NULL,statistic=NULL) {
   pp<-NULL; st.diff<-NULL;d<-NULL;sv<-NULL
   for (i in (1:nc)) {
     t1<-table(varsdt[,i],factor(xvt),useNA="no")
-    pvalue<-chisq.test(t1,correct=FALSE)$p.value;svv1<-chisq.test(t1,correct=FALSE)[["statistic"]]
-    pp1<-ifelse(pvalue<0.001, "<0.001", pvformat(pvalue,3));sv1<-ifelse(svv1<0.001, "<0.001",pvformat(svv1,3))
-    ooi<-cbind(matrix(rep(" ",times=ncol(t1)),nrow=1), pp1)
+    Overall.t1<-table(varsdt[,i],useNA="no")
+    if (fisher==FALSE) {
+      pvalue<-chisq.test(t1,correct=correct)$p.value;svv1<-chisq.test(t1,correct=correct)[["statistic"]]
+    } else if (fisher==TRUE) {
+      pvalue<-fisher.test(t1)$p.value;svv1<-""} else {
+        stop("Fisher can only take the value FALSE or TRUE")
+      }
+    pp1<-ifelse(pvalue<0.001, "<0.001", pvformat(pvalue,3));
+    if (fisher==FALSE) {sv1<-ifelse(svv1<0.001, "<0.001",pvformat(svv1,3))}
+    if (fisher==T) {sv1<-""}
+    if (Overall==FALSE) {
+      ooi<-cbind(matrix(rep(" ",times=ncol(t1)),nrow=1), pp1)
+    } else {
+      ooi<-cbind("Overall",matrix(rep(" ",times=ncol(t1)),nrow=1), pp1)
+    }
     p1<-prop.table(t1,2)
+    Overall.p1<-Overall.t1/length(varsdt[,i])
     tb1<-matrix(paste(format(t1)," (", numfmt(p1*100,dec), "%)", sep=""),nrow=nrow(t1))
+    Overall.tb1<-matrix(paste(format(Overall.t1)," (", numfmt(Overall.p1*100,dec), "%)", sep=""),
+                        nrow=nrow(Overall.p1))
+    varnames<-paste(x,".",levels(factor(xvt)),sep="")
+    if (Overall==T) {
+      tb1<-cbind(Overall.tb1,tb1)
+      varnames<-c("Overall",varnames)
+    }
     tmp.names<-c(mvars[i],rownames(t1))
     if (statistic==T) {
       d1<-cbind(rownames(t1),tb1,rep(" ",times=length(rownames(t1))),rep(" ",times=length(rownames(t1))))
+      varnames<-c(varnames,"statistic")
     } else {d1<-cbind(rownames(t1),tb1,rep(" ",times=length(rownames(t1))))}
-    if (statistic==T){
+    if (statistic==T & Overall==T) {
+      d2<-c(mvars[i],"",rep(" ",times=n.x),sv1,pp1)
+    } else if (statistic==T){
       d2<-c(mvars[i],rep(" ",times=n.x),sv1,pp1)
     } else {d2<-c(mvars[i],rep(" ",times=n.x),pp1)}
     d0<-rbind(d2,d1)
     d<-rbind(d,d0)
   }
-  tmp.cname1<-paste(x,".",levels(factor(xvt)),sep="")
-  if (statistic==T) {
-    colnames(d)<-c("Characteristic",tmp.cname1,"statistic","p value")
-  } else {colnames(d)<-c("Characteristic",tmp.cname1,"p value")}
+  colnames(d)<-c("Characteristic",varnames,"p value")
   d
 }
+
